==> sghi_core-0.2.31.tar.gz: lib/app_wrapper/endpoints.dart <==
/* PROD ENDPOINTS */

/// the prod graphql endpoint
const String kProdGraphqlEndpoint = 'https://graph.bewell.co.ke/graphql';
const String kProdLoginByPhoneEndpoint =
    'https://profile-prod.healthcloud.co.ke/login_by_phone';
const String kProdPinResetEndpoint =
    'https://profile-prod.healthcloud.co.ke/request_pin_reset';
const String kProdUpdateUserPinEndpoint =
    'https://profile-prod.healthcloud.co.ke/reset_pin';
const String kProdVerifyPhoneEndpoint =
    'https://profile-prod.healthcloud.co.ke/verify_phone';
const String kProdCreateUserByPhoneEndpoint =
    'https://profile-prod.healthcloud.co.ke/create_user_by_phone';
const String kProdRetryResendOtpEndpoint =
    'https://profile-prod.healthcloud.co.ke/send_retry_otp';
const String kProdRefreshTokenEndpoint =
    'https://profile-prod.healthcloud.co.ke/refresh_token';
const String kProdAnonymousLoginEndpoint =
    'https://profile-prod.healthcloud.co.ke/login_anonymous';
const String kProdUserRecoveryPhoneNumbersEndpoint =
    'https://profile-prod.healthcloud.co.ke/user_recovery_phonenumbers';
const String kProdSendRecoverAccountOtpEndpoint =
    'https://profile-prod.healthcloud.co.ke/send_otp';
const String kProdSetPrimaryPhoneNumberEndpoint =
    'https://profile-prod.healthcloud.co.ke/set_primary_phonenumber';
const String kProdSwitchFlaggedFeaturesEndpoint =
    'https://profile-prod.healthcloud.co.ke/switch_flagged_features';
const String kProdUploadFileEndPoint =
    'https://engagement-prod.healthcloud.co.ke/upload';

/* TEST ENDPOINTS */
const String kTestGraphqlEndpoint = 'https://graph-test.bewell.co.ke/graphql';
const String kTestLoginByPhoneEndpoint =
    'https://profile-testing.healthcloud.co.ke/login_by_phone';
const String kTestPinResetEndpoint =
    'https://profile-testing.healthcloud.co.ke/request_pin_reset';
const String kTestUpdateUserPinEndpoint =
    'https://profile-testing.healthcloud.co.ke/reset_pin';
const String kTestVerifyPhoneEndpoint =
    'https://profile-testing.healthcloud.co.ke/verify_phone';
const String kTestCreateUserByPhoneEndpoint =
    'https://profile-testing.healthcloud.co.ke/create_user_by_phone';
const String kTestRetryResendOtpEndpoint =
    'https://profile-testing.healthcloud.co.ke/send_retry_otp';
const String kTestRefreshTokenEndpoint =
    'https://profile-testing.healthcloud.co.ke/refresh_token';
const String kTestAnonymousLoginEndpoint =
    'https://profile-testing.healthcloud.co.ke/login_anonymous';
const String kTestUserRecoveryPhoneNumbersEndpoint =
    'https://profile-testing.healthcloud.co.ke/user_recovery_phonenumbers';
const String kTestSendRecoverAccountOtpEndpoint =
    'https://profile-testing.healthcloud.co.ke/send_otp';
const String kTestSetPrimaryPhoneNumberEndpoint =
    'https://profile-testing.healthcloud.co.ke/set_primary_phonenumber';
const String kTestSwitchFlaggedFeaturesEndpoint =
    'https://profile-testing.healthcloud.co.ke/switch_flagged_features';
const String kTestUploadFileEndPoint =
    'https://engagement-testing.healthcloud.co.ke/upload';

/* DEMO ENDPOINTS */
const String kDemoGraphqlEndpoint = 'https://graph-demo.bewell.co.ke/graphql';
const String kDemoLoginByPhoneEndpoint =
    'https://profile-demo.healthcloud.co.ke/login_by_phone';
const String kDemoPinResetEndpoint =
    'https://profile-demo.healthcloud.co.ke/request_pin_reset';
const String kDemoUpdateUserPinEndpoint =
    'https://profile-demo.healthcloud.co.ke/reset_pin';
const String kDemoVerifyPhoneEndpoint =
    'https://profile-demo.healthcloud.co.ke/verify_phone';
const String kDemoCreateUserByPhoneEndpoint =
    'https://profile-demo.healthcloud.co.ke/create_user_by_phone';
const String kDemoRetryResendOtpEndpoint =
    'https://profile-demo.healthcloud.co.ke/send_retry_otp';
const String kDemoRefreshTokenEndpoint =
    'https://profile-demo.healthcloud.co.ke/refresh_token';
const String kDemoAnonymousLoginEndpoint =
    'https://profile-demo.healthcloud.co.ke/login_anonymous';
const String kDemoUserRecoveryPhoneNumbersEndpoint =
    'https://profile-demo.healthcloud.co.ke/user_recovery_phonenumbers';
const String kDemoSendRecoverAccountOtpEndpoint =
    'https://profile-demo.healthcloud.co.ke/send_otp';
const String kDemoSetPrimaryPhoneNumberEndpoint =
    'https://profile-demo.healthcloud.co.ke/set_primary_phonenumber';
const String kDemoSwitchFlaggedFeaturesEndpoint =
    'https://profile-demo.healthcloud.co.ke/switch_flagged_features';
const String kDemoUploadFileEndPoint =
    'https://engagement-demo.healthcloud.co.ke/upload';

/* E2E ENDPOINTS */
const String ke2eGraphqlEndpoint = 'https://graph-e2e.bewell.co.ke/graphql';
const String ke2eLoginByPhoneEndpoint =
    'https://profile-e2e.healthcloud.co.ke/login_by_phone';
const String ke2ePinResetEndpoint =
    'https://profile-e2e.healthcloud.co.ke/request_pin_reset';
const String ke2eUpdateUserPinEndpoint =
    'https://profile-e2e.healthcloud.co.ke/reset_pin';
const String ke2eVerifyPhoneEndpoint =
    'https://profile-e2e.healthcloud.co.ke/verify_phone';
const String ke2eCreateUserByPhoneEndpoint =
    'https://profile-e2e.healthcloud.co.ke/create_user_by_phone';
const String ke2eRetryResendOtpEndpoint =
    'https://profile-e2e.healthcloud.co.ke/send_retry_otp';
const String ke2eRefreshTokenEndpoint =
    'https://profile-e2e.healthcloud.co.ke/refresh_token';
const String ke2eAnonymousLoginEndpoint =
    'https://profile-e2e.healthcloud.co.ke/login_anonymous';
const String ke2eUserRecoveryPhoneNumbersEndpoint =
    'https://profile-e2e.healthcloud.co.ke/user_recovery_phonenumbers';
const String ke2eSendRecoverAccountOtpEndpoint =
    'https://profile-e2e.healthcloud.co.ke/send_otp';
const String ke2eSetPrimaryPhoneNumberEndpoint =
    'https://profile-e2e.healthcloud.co.ke/set_primary_phonenumber';
const String ke2eSwitchFlaggedFeaturesEndpoint =
    'https://profile-e2e.healthcloud.co.ke/switch_flagged_features';
const String ke2eUploadFileEndPoint =
    'https://engagement-e2e.healthcloud.co.ke/upload';

==> sghi_core-0.2.33.tar.gz: lib/app_wrapper/endpoints.dart <==
/* PROD ENDPOINTS */

/// the prod graphql endpoint
const String kProdGraphqlEndpoint = 'https://graph.bewell.co.ke/graphql';
const String kProdLoginByPhoneEndpoint =
    'https://profile-prod.healthcloud.co.ke/login_by_phone';
const String kProdPinResetEndpoint =
    'https://profile-prod.healthcloud.co.ke/request_pin_reset';
const String kProdUpdateUserPinEndpoint =
    'https://profile-prod.healthcloud.co.ke/reset_pin';
const String kProdVerifyPhoneEndpoint =
    'https://profile-prod.healthcloud.co.ke/verify_phone';
const String kProdCreateUserByPhoneEndpoint =
    'https://profile-prod.healthcloud.co.ke/create_user_by_phone';
const String kProdRetryResendOtpEndpoint =
    'https://profile-prod.healthcloud.co.ke/send_retry_otp';
const String kProdRefreshTokenEndpoint =
    'https://profile-prod.healthcloud.co.ke/refresh_token';
const String kProdAnonymousLoginEndpoint =
    'https://profile-prod.healthcloud.co.ke/login_anonymous';
const String kProdUserRecoveryPhoneNumbersEndpoint =
    'https://profile-prod.healthcloud.co.ke/user_recovery_phonenumbers';
const String kProdSendRecoverAccountOtpEndpoint =
    'https://profile-prod.healthcloud.co.ke/send_otp';
const String kProdSetPrimaryPhoneNumberEndpoint =
    'https://profile-prod.healthcloud.co.ke/set_primary_phonenumber';
const String kProdSwitchFlaggedFeaturesEndpoint =
    'https://profile-prod.healthcloud.co.ke/switch_flagged_features';
const String kProdUploadFileEndPoint = 'https://engagement.bewell.co.ke/upload';

/* TEST ENDPOINTS */
const String kTestGraphqlEndpoint = 'https://graph-test.bewell.co.ke/graphql';
const String kTestLoginByPhoneEndpoint =
    'https://profile-testing.healthcloud.co.ke/login_by_phone';
const String kTestPinResetEndpoint =
    'https://profile-testing.healthcloud.co.ke/request_pin_reset';
const String kTestUpdateUserPinEndpoint =
    'https://profile-testing.healthcloud.co.ke/reset_pin';
const String kTestVerifyPhoneEndpoint =
    'https://profile-testing.healthcloud.co.ke/verify_phone';
const String kTestCreateUserByPhoneEndpoint =
    'https://profile-testing.healthcloud.co.ke/create_user_by_phone';
const String kTestRetryResendOtpEndpoint =
    'https://profile-testing.healthcloud.co.ke/send_retry_otp';
const String kTestRefreshTokenEndpoint =
    'https://profile-testing.healthcloud.co.ke/refresh_token';
const String kTestAnonymousLoginEndpoint =
    'https://profile-testing.healthcloud.co.ke/login_anonymous';
const String kTestUserRecoveryPhoneNumbersEndpoint =
    'https://profile-testing.healthcloud.co.ke/user_recovery_phonenumbers';
const String kTestSendRecoverAccountOtpEndpoint =
    'https://profile-testing.healthcloud.co.ke/send_otp';
const String kTestSetPrimaryPhoneNumberEndpoint =
    'https://profile-testing.healthcloud.co.ke/set_primary_phonenumber';
const String kTestSwitchFlaggedFeaturesEndpoint =
    'https://profile-testing.healthcloud.co.ke/switch_flagged_features';
const String kTestUploadFileEndPoint =
    'https://engagement.uat.bewell.slade360edi.com/upload';

/* DEMO ENDPOINTS */
const String kDemoGraphqlEndpoint = 'https://graph-demo.bewell.co.ke/graphql';
const String kDemoLoginByPhoneEndpoint =
    'https://profile-demo.healthcloud.co.ke/login_by_phone';
const String kDemoPinResetEndpoint =
    'https://profile-demo.healthcloud.co.ke/request_pin_reset';
const String kDemoUpdateUserPinEndpoint =
    'https://profile-demo.healthcloud.co.ke/reset_pin';
const String kDemoVerifyPhoneEndpoint =
    'https://profile-demo.healthcloud.co.ke/verify_phone';
const String kDemoCreateUserByPhoneEndpoint =
    'https://profile-demo.healthcloud.co.ke/create_user_by_phone';
const String kDemoRetryResendOtpEndpoint =
    'https://profile-demo.healthcloud.co.ke/send_retry_otp';
const String kDemoRefreshTokenEndpoint =
    'https://profile-demo.healthcloud.co.ke/refresh_token';
const String kDemoAnonymousLoginEndpoint =
    'https://profile-demo.healthcloud.co.ke/login_anonymous';
const String kDemoUserRecoveryPhoneNumbersEndpoint =
    'https://profile-demo.healthcloud.co.ke/user_recovery_phonenumbers';
const String kDemoSendRecoverAccountOtpEndpoint =
    'https://profile-demo.healthcloud.co.ke/send_otp';
const String kDemoSetPrimaryPhoneNumberEndpoint =
    'https://profile-demo.healthcloud.co.ke/set_primary_phonenumber';
const String kDemoSwitchFlaggedFeaturesEndpoint =
    'https://profile-demo.healthcloud.co.ke/switch_flagged_features';
const String kDemoUploadFileEndPoint =
    'https://engagement.uat.bewell.slade360edi.com/upload';

/* E2E ENDPOINTS */
const String ke2eGraphqlEndpoint = 'https://graph-e2e.bewell.co.ke/graphql';
const String ke2eLoginByPhoneEndpoint =
    'https://profile-e2e.healthcloud.co.ke/login_by_phone';
const String ke2ePinResetEndpoint =
    'https://profile-e2e.healthcloud.co.ke/request_pin_reset';
const String ke2eUpdateUserPinEndpoint =
    'https://profile-e2e.healthcloud.co.ke/reset_pin';
const String ke2eVerifyPhoneEndpoint =
    'https://profile-e2e.healthcloud.co.ke/verify_phone';
const String ke2eCreateUserByPhoneEndpoint =
    'https://profile-e2e.healthcloud.co.ke/create_user_by_phone';
const String ke2eRetryResendOtpEndpoint =
    'https://profile-e2e.healthcloud.co.ke/send_retry_otp';
const String ke2eRefreshTokenEndpoint =
    'https://profile-e2e.healthcloud.co.ke/refresh_token';
const String ke2eAnonymousLoginEndpoint =
    'https://profile-e2e.healthcloud.co.ke/login_anonymous';
const String ke2eUserRecoveryPhoneNumbersEndpoint =
    'https://profile-e2e.healthcloud.co.ke/user_recovery_phonenumbers';
const String ke2eSendRecoverAccountOtpEndpoint =
    'https://profile-e2e.healthcloud.co.ke/send_otp';
const String ke2eSetPrimaryPhoneNumberEndpoint =
    'https://profile-e2e.healthcloud.co.ke/set_primary_phonenumber';
const String ke2eSwitchFlaggedFeaturesEndpoint =
    'https://profile-e2e.healthcloud.co.ke/switch_flagged_features';
const String ke2eUploadFileEndPoint =
    'https://engagement.uat.bewell.slade360edi.com/upload';
